==> javapos-contracts-1.10.0-sources.jar: jpos/services/MSRService110.java <==
//////////////////////////////////////////////////////////////////////
//
// The JavaPOS library source code is now under the CPL license, which 
// is an OSS Apache-like license. The complete license is located at:
//    http://www.ibm.com/developerworks/library/os-cpl.html
//
//////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////
//
// This software is provided "AS IS".  The JavaPOS working group (including
// each of the Corporate members, contributors and individuals)  MAKES NO
// REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE SOFTWARE,
// EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
// WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NON-INFRINGEMENT. The JavaPOS working group shall not be liable for
// any damages suffered as a result of using, modifying or distributing this
// software or its derivatives.Permission to use, copy, modify, and distribute
// the software and its documentation for any purpose is hereby granted.
//
// MSRService110
//
//   Interface definining all new capabilities, properties and
//   methods that are specific to MSR for release 1.10.
//
// Modification history
// ------------------------------------------------------------------
// 2006-Feb-10 JavaPOS Release 1.10                                BS
//
/////////////////////////////////////////////////////////////////////

package jpos.services;

import jpos.*;

public interface MSRService110
  extends MSRService19
{
  // Capabilities
  public int     getCapWritableTracks()
                     throws JposException;

  // Properties
  public int     getEncodingMaxLength()
                     throws JposException;
  public int     getTracksToWrite()
                     throws JposException;
  public void    setTracksToWrite(int tracks)
                     throws JposException;

  // Methods
  public void    clearInputProperties()
                     throws JposException;
  public void    writeTracks(String data, int timeout)
                     throws JposException;
}

==> javapos-contracts-1.14.2-sources.jar: jpos/services/MSRService110.java <==
//////////////////////////////////////////////////////////////////////
//
// The JavaPOS library source code is now under the CPL license, which 
// is an OSS Apache-like license. The complete license is located at:
//    http://www.ibm.com/developerworks/library/os-cpl.html
//
//////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////
//
// This software is provided "AS IS".  The JavaPOS working group (including
// each of the Corporate members, contributors and individuals)  MAKES NO
// REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE SOFTWARE,
// EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
// WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NON-INFRINGEMENT. The JavaPOS working group shall not be liable for
// any damages suffered as a result of using, modifying or distributing this
// software or its derivatives.Permission to use, copy, modify, and distribute
// the software and its documentation for any purpose is hereby granted.
//
// MSRService110
//
//   Interface definining all new capabilities, properties and
//   methods that are specific to MSR for release 1.10.
//
// Modification history
// ------------------------------------------------------------------
// 2006-Feb-10 JavaPOS Release 1.10                                BS
// 2006-Oct-23 JavaPOS 1.10.2 Update                               BS
//   Fixed type of writeTracks data parameter to be byte[][] as
//   UnifiedPOS has corrected the type from "string" to
//   "array of binary".
//
/////////////////////////////////////////////////////////////////////

package jpos.services;

import jpos.*;

public interface MSRService110
  extends MSRService19
{
  // Capabilities
  public int     getCapWritableTracks()
                     throws JposException;

  // Properties
  public int     getEncodingMaxLength()
                     throws JposException;
  public int     getTracksToWrite()
                     throws JposException;
  public void    setTracksToWrite(int tracks)
                     throws JposException;

  // Methods
  public void    clearInputProperties()
                     throws JposException;
  public void    writeTracks(byte[][] data, int timeout)
                     throws JposException;
}
